@@ -20,43 +20,20 @@
 // along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <Rcpp/Environment.h>
-#include <Rcpp/Evaluator.h>
-#include <Rcpp/Symbol.h>
-#include <Rcpp/Language.h>
-#include <Rcpp/wrap.h>
 
 namespace Rcpp {
 
-/* this comes from JRI, where it was introduced to cope with cases
-   where bindings are locked */
-struct safeAssign_s {
-    SEXP sym, val, rho;
-};
-static void safeAssign(void *data) {
-    struct safeAssign_s *s = (struct safeAssign_s*) data;
-    Rf_defineVar(s->sym, s->val, s->rho);
-}
-
-struct safeFindNamespace_s {
-    SEXP sym, val ;
-};
-static void safeFindNamespace(void *data) {
-    struct safeFindNamespace_s *s = (struct safeFindNamespace_s*) data;
-    s->val = R_FindNamespace(s->sym);
-}
-
     Environment::Environment( SEXP x = R_GlobalEnv) throw(not_compatible) : RObject::RObject(x){
     	if( ! Rf_isEnvironment(x) ) {
-    		
     		/* not an environment, but maybe convertible to one using 
     		   as.environment, try that */
-    		Evaluator evaluator( Rf_lang2(Symbol("as.environment"), x ) ) ;
-    		evaluator.run() ;
-    		if( evaluator.successfull() ){
-    			setSEXP( evaluator.getResult().asSexp() ) ;
-    		} else{
+    		SEXP res ;
+    		try{
+    			res = Evaluator::run( Rf_lang2(Rf_install("as.environment"), x ) ) ;
+    		} catch( const Evaluator::eval_error& ex){
     			throw not_compatible( "cannot convert to environment"  ) ; 
     		}
+    		setSEXP( res ) ;
     	}
     }
 
@@ -67,24 +44,25 @@ static void safeFindNamespace(void *data) {
     	} else if( name == "package:base" ){
     		setSEXP( R_BaseEnv ) ;
     	} else{
-    		Evaluator evaluator( Rf_lang2(Symbol("as.environment"), Rf_mkString(name.c_str()) ) ) ;
-    		evaluator.run() ;
-    		if( evaluator.successfull() ){
-    			setSEXP( evaluator.getResult().asSexp() ) ;
-    		} else{
-    			throw no_such_env(name) ; 
+    		SEXP res = R_NilValue ;
+    		try{
+    			res = Evaluator::run( 
+    				Rf_lang2( Rf_install("as.environment"), Rf_mkString(name.c_str()) ) ) ;
+    		} catch( const Evaluator::eval_error& ex){
+    			throw no_such_env(name) ;
     		}
+    		setSEXP( res ) ;
     	}
     }
     
     Environment::Environment(int pos) throw(no_such_env) : RObject(R_GlobalEnv){
-    	Evaluator evaluator( Rf_lang2(Symbol("as.environment"), Rf_ScalarInteger(pos) ) ) ;
-    	evaluator.run() ;
-    	if( evaluator.successfull() ){
-    		setSEXP( evaluator.getResult() ) ;
-    	} else{
-    		throw no_such_env(pos) ; 
-    	}
+    	   SEXP res ;
+    	   try{
+    	   	   res =  Evaluator::run( Rf_lang2( Rf_install("as.environment"), Rf_ScalarInteger(pos) ) ) ;
+    	   } catch( const Evaluator::eval_error& ex){
+    	   	   throw no_such_env(pos) ;
+    	   }
+    	   setSEXP( res ) ;
     }
     
     Environment::Environment( const Environment& other ) throw() {
@@ -131,19 +109,8 @@ static void safeFindNamespace(void *data) {
     
     bool Environment::assign( const std::string& name, SEXP x = R_NilValue) const throw(binding_is_locked){
     	if( exists( name) && bindingIsLocked(name) ) throw binding_is_locked(name) ;
-    	
-    	/* borrowed from JRI, we cannot just use defineVar since it might 
-    	   crash on locked bindings */
-    	   
-    	/* TODO: we need to modify R_ToplevelExec so that it does not print 
-    	         the error message as it currently does*/
-    	struct safeAssign_s s;
-    	s.sym = Rf_install( name.c_str() ) ;
-    	if( !s.sym || s.sym == R_NilValue ) return false ;
-    	
-    	s.rho = m_sexp ;
-    	s.val = x ;
-    	return static_cast<bool>( R_ToplevelExec(safeAssign, (void*) &s) );
+    	Rf_defineVar( Rf_install( name.c_str() ) , x, m_sexp );
+    	return true ;
     }
     
     bool Environment::remove( const std::string& name) throw(binding_is_locked){
@@ -222,12 +189,14 @@ static void safeFindNamespace(void *data) {
     }
     
     Environment Environment::namespace_env(const std::string& package) throw(no_such_namespace) {
-    	struct safeFindNamespace_s s;
-    	s.sym = Rf_mkString( package.c_str() ) ;
-    	if( !s.sym || s.sym == R_NilValue || !R_ToplevelExec(safeFindNamespace, (void*) &s) ){
-    		throw no_such_namespace(package) ;
+    	
+    	SEXP env = R_NilValue ;
+    	try{
+    		env = Evaluator::run( Rf_lang2(Rf_install("getNamespace"), Rf_mkString(package.c_str()) ) ) ;
+    	} catch( const Evaluator::eval_error& ex){
+    		throw no_such_namespace( package  ) ; 
     	}
-    	return s.val ;
+    	return Environment( env ) ;
     }
     
     Environment Environment::parent() const throw() {
@@ -304,11 +273,7 @@ static void safeFindNamespace(void *data) {
     Environment::Binding::operator SEXP() const{
     	return env.get( name );    
     }
-    
-    Environment::Binding::operator RObject() const{
-    	return wrap( env.get( name ) );
-    }
-    
+
     const Environment::Binding Environment::operator[]( const std::string& name) const{
     	return Binding( const_cast<Environment&>(*this), name );
     }
@@ -317,5 +282,17 @@ static void safeFindNamespace(void *data) {
     	return Binding( *this, name ) ;
     }
     
+    Environment Environment::Rcpp_namespace() throw() {
+    	    return Environment( Rf_eval( Rf_lcons( Rf_install("getNamespace"), Rf_cons( Rf_mkString("Rcpp") , R_NilValue) ), R_GlobalEnv ) ) ;
+    }
+    
+    Environment Environment::new_child(bool hashed) {
+    	    return Environment( Evaluator::run( 
+    	    	    Rf_lcons( Rf_install("new.env"), 
+    	    	    	    Rf_cons(Rf_ScalarLogical(hashed), 
+    	    	    	    	    Rf_cons(m_sexp,R_NilValue)) ) ) );
+    }
+    
+    
 } // namespace Rcpp
 
