@@ -23,42 +23,11 @@
 #define Rcpp_ComplexVector_h
 
 #include <RcppCommon.h>
-#include <Rcpp/RObject.h>
-
-#ifdef HAS_INIT_LISTS
-#include <initializer_list>
-#include <algorithm>
-#endif
+#include <Rcpp/SimpleVector.h>
 
 namespace Rcpp{ 
 
-class ComplexVector : public RObject {     
-public:
-
-	ComplexVector(SEXP x) throw(not_compatible);
-	ComplexVector(int size) ;
-	
-#ifdef HAS_INIT_LISTS	
-	ComplexVector( std::initializer_list<Rcomplex> list ) ;
-#endif
-	
-	/**
-	 * the length of the vector, uses Rf_length
-	 */
-	inline int length() const { return Rf_length( m_sexp ) ; }
-	
-	/**
-	 * alias of length
-	 */
-	inline int size() const { return Rf_length( m_sexp ) ; }
-	
-	Rcomplex& operator[]( int i ) const throw(index_out_of_bounds) ;
-	Rcomplex* begin() const ; 
-	Rcomplex* end() const ;
-	
-	typedef Rcomplex* iterator ;
-	
-} ;
+typedef SimpleVector<CPLXSXP,Rcomplex> ComplexVector ;	
 
 } // namespace
 
