@@ -23,43 +23,11 @@
 #define Rcpp_IntegerVector_h
 
 #include <RcppCommon.h>
-#include <Rcpp/RObject.h>
-
-#ifdef HAS_INIT_LISTS
-#include <initializer_list>
-#include <algorithm>
-#endif
+#include <Rcpp/SimpleVector.h>
 
 namespace Rcpp{ 
 
-class IntegerVector : public RObject {     
-public:
-
-	IntegerVector(SEXP x) throw(not_compatible);
-	IntegerVector( int size) ;
-	
-#ifdef HAS_INIT_LISTS	
-	IntegerVector( std::initializer_list<int> list ) ;
-	IntegerVector( std::initializer_list<double> list ) ;
-#endif
-	
-	/**
-	 * the length of the vector, uses Rf_length
-	 */
-	inline int length() const { return Rf_length( m_sexp ) ; }
-	
-	/**
-	 * alias of length
-	 */
-	inline int size() const { return Rf_length( m_sexp ) ; }
-	
-	int& operator[]( int i ) const throw(index_out_of_bounds) ;
-	int* begin() const ; 
-	int* end() const ;
-	
-	typedef int* iterator ;
-	
-} ;
+typedef SimpleVector<INTSXP,int> IntegerVector ;
 
 } // namespace
 
