@@ -20,11 +20,26 @@
 // along with Rcpp.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <RcppCommon.h>
-#include <Rcpp/RObject.h>
 #include <Rcpp/VectorBase.h>
 
 namespace Rcpp{
-	VectorBase::VectorBase(): RObject(){} ;
+	
+	VectorBase::VectorBase() : RObject() {} ;
 	VectorBase::~VectorBase(){}
+	
+	size_t VectorBase::offset( const size_t& i, const size_t& j) const throw(not_a_matrix,RObject::index_out_of_bounds) {
+		if( !Rf_isMatrix(m_sexp) ) throw VectorBase::not_a_matrix() ;
+		/* we need to extract the dimensions */
+		int *dim = INTEGER( Rf_getAttrib( m_sexp, R_DimSymbol ) ) ;
+		size_t nrow = static_cast<size_t>(dim[0]) ;
+		size_t ncol = static_cast<size_t>(dim[1]) ;
+		if( i >= nrow || j >= ncol ) throw RObject::index_out_of_bounds() ;
+		return i + nrow*j ;
+	}
+
+	size_t VectorBase::offset(const size_t& i) const throw(RObject::index_out_of_bounds){
+    	    if( i >= static_cast<size_t>(Rf_length(m_sexp)) ) throw RObject::index_out_of_bounds() ;
+    	    return i ;
+    	}
 
 } // namespace 
